gogarchspec,
gogarchfit, gogarchfilter, gogarchforecast,
gogarchsim and gogarchroll functions. The DCC
with multivariate Normal, Laplace and Student distributions is also supported
with the main functionality in dccspec, dccfit,
dccfilter, dccforecast, dccsim and
dccroll. The Normal and Student Copula-GARCH, with dynamic or
static correlation, is implemented with the main functionality in
cgarchspec, cgarchfit, cgarchfilter,
and cgarchsim. Usual extractor and support methods for the
multivariate GARCH models are documented in the class of the returned objects.
.